@@ -123,6 +123,10 @@ public class BatchTestUtils {
 
 	public static void compileInModuleMode(JavaCompiler compiler, List<String> options, String processor,
 			File targetFolder, DiagnosticListener<? super JavaFileObject> listener, boolean multiModule) {
+		compileInModuleMode(compiler, options, processor, targetFolder, listener, multiModule, true);
+	}
+	public static void compileInModuleMode(JavaCompiler compiler, List<String> options, String processor,
+			File targetFolder, DiagnosticListener<? super JavaFileObject> listener, boolean multiModule, boolean processBinariesAgain) {
 		StandardJavaFileManager manager = compiler.getStandardFileManager(null, Locale.getDefault(), Charset.defaultCharset());
 		Iterable<? extends File> location = manager.getLocation(StandardLocation.CLASS_PATH);
 		// create new list containing inputfile
@@ -151,6 +155,9 @@ public class BatchTestUtils {
 			System.err.println("Compilation failed: " + errorOutput);
 	 		junit.framework.TestCase.assertTrue("Compilation failed : " + errorOutput, false);
 		}
+		if (!processBinariesAgain) {
+			return;
+		}
 		List<String> classes = new ArrayList<>();
 		try {
 			manager = compiler.getStandardFileManager(null, Locale.getDefault(), Charset.defaultCharset());
