@@ -1,9 +1,12 @@
 /*******************************************************************************
  * Copyright (c) 2017, 2018 Till Brychcy and others.
- * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
+ *
+ * This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License 2.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * https://www.eclipse.org/legal/epl-2.0/
+ *
+ * SPDX-License-Identifier: EPL-2.0
  *
  * Contributors:
  *     Till Brychcy - initial API and implementation
@@ -838,6 +841,7 @@ public class TestAttributeBuilderTests extends BuilderTests {
 
 		// project X just reexports Project1 without test code
 		IPath projectXPath = env.addProject("ProjectX"); 
+		env.removePackageFragmentRoot(projectXPath, "");
 		env.addRequiredProjectWithoutTestCode(projectXPath, project1Path, /* isExported */ true);
 		
 
