@@ -1,9 +1,12 @@
 /*******************************************************************************
  * Copyright (c) 2005, 2014 IBM Corporation and others.
- * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
+ *
+ * This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License 2.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * https://www.eclipse.org/legal/epl-2.0/
+ *
+ * SPDX-License-Identifier: EPL-2.0
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
@@ -894,6 +897,8 @@ public void testBug537033() {
 			"    }\n" + 
 			"}\n"
 		},
+		this.complianceLevel < ClassFileConstants.JDK11
+		?
 		"----------\n" + 
 		"1. WARNING in ShowBug.java (at line 9)\n" + 
 		"	final X x = new X() {\n" + 
@@ -904,6 +909,13 @@ public void testBug537033() {
 		"	x.x(val - 1);\n" + 
 		"	^\n" + 
 		"The local variable x may not have been initialized\n" + 
+		"----------\n"
+		:
+		"----------\n" + 
+		"1. ERROR in ShowBug.java (at line 13)\n" + 
+		"	x.x(val - 1);\n" + 
+		"	^\n" + 
+		"The local variable x may not have been initialized\n" + 
 		"----------\n");
 }
 public static Class testClass() {
