@@ -1,9 +1,12 @@
 /*******************************************************************************
  * Copyright (c) 2016, 2018 IBM Corporation and others.
- * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
+ *
+ * This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License 2.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * https://www.eclipse.org/legal/epl-2.0/
+ *
+ * SPDX-License-Identifier: EPL-2.0
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
@@ -64,8 +67,13 @@ public class ASTConverter9Test extends ConverterTestSetup {
 	}
 	public static Test suite() {
 		String javaVersion = System.getProperty("java.version");
-		if (javaVersion.length() > 3) {
-			javaVersion = javaVersion.substring(0, 3);
+		int index = -1;
+		if ( (index = javaVersion.indexOf('-')) != -1) {
+			javaVersion = javaVersion.substring(0, index);
+		} else {
+			if (javaVersion.length() > 3) {
+				javaVersion = javaVersion.substring(0, 3);
+			}
 		}
 		long jdkLevel = CompilerOptions.versionToJdkLevel(javaVersion);
 		if (jdkLevel >= ClassFileConstants.JDK9) {
